@@ -141,7 +141,7 @@ def format_list(result):
             stringfiles = " [" + ", ".join(gist_names) + "]"
             gists_string += colored.red(stringfiles)
             if not gist.public:
-                gists_string += " (Private) "
+                gists_string += " (Private Gist) "
             gists_string += '\n'
 
         # Set the footer
@@ -163,6 +163,20 @@ def format_authorize(result):
         return __format_error(result.data)
 
 
+def format_star(result):
+    """ Formats the output of the 'star' and 'unstar' action.
+
+    :param result: Result instance
+    """
+
+    if result.success:
+        # The result is just a string informing the success
+        return result.data
+    else:
+        # Format the error string message
+        return __format_error(result.data)
+
+
 def __format_gist(gist):
     """ Formats the output for a Gist metadata object.
 
@@ -189,8 +203,7 @@ def __format_gist(gist):
     gists_string += str(not gist.public) + '\n'
 
     gists_string += colored.green('Files:\t\t')
-    gist_names = [gistfile.filename for
-                    gistfile in gist.files]
+    gist_names = [gistfile.filename for gistfile in gist.files]
     stringfiles = "[" + ", ".join(gist_names) + "]"
     gists_string += colored.red(stringfiles) + '\n'
 
